@@ -62,6 +62,7 @@ class dyagram:
                                       "username": self.username,
                                       "password": self.password,
                                       "secret": self.password,
+                                      "global_delay": 3,
                                       "banner_timeout": 200}
 
 
@@ -129,7 +130,7 @@ class dyagram:
                 self._discover_lldp_neighbors_by_ssh(device)
                 self.pbar.update(self.pbar_update_int)
                 self.log.info(f"DEVICE: {device} - SSH : Discovering LLDP Neighbors - SUCCESSFUL")
-            except Exception:
+            except:
                 tb = self.get_traceback()
                 self.log.info(f"DEVICE: {device} EXCEPTION01 THROWN IN __discover_lldp_neighbors : {tb}")
 
@@ -169,13 +170,12 @@ class dyagram:
                 except queue.Empty:
                     self.log.info(f"QUEUE EMPTY")
                     queue_empty = True
-                except Exception:
+                except:
                     tb = self.get_traceback()
                     self.log.info(f"EXCEPTION THROWN IN PULLING FROM QUEUE: {tb}")
-            time.sleep(25)
-            print("BEFORE SHUT")
+
             executor.shutdown(wait=True)
-            print("AFTER SHUT")
+
             #sort topology by hostname to compare to previous
 
             self.topology['devices'] = sorted(self.topology['devices'], key=lambda d: d['hostname'])
@@ -264,7 +264,8 @@ class dyagram:
                             "username": self.username,
                             "password": self.password,
                             "secret": self.password,
-                            "banner_timeout": 200
+                            "banner_timeout": 200,
+                            "global_delay": 3
                             }
             # autodetect_tries = 0
             # while autodetect_tries < 10:
@@ -328,14 +329,15 @@ class dyagram:
 
 
     def get_device_type(self, device):
-
+        #time.sleep(5)  # FIXME: IF I DON'T PUT THIS HERE THERE IS AN EXCEPTION THROWN THAT I CAN'T CATCH
         try:
 
             autodetect_netmiko_args = {"device_type": "autodetect",
                                        "host": device,
                                        "username": self.username,
                                        "password": self.password,
-                                       "banner_timeout": 200}
+                                       "banner_timeout": 30,
+                                       "global_delay": 3}
             autodetect_tries = 0
             while autodetect_tries < 10:
                 try:
@@ -392,7 +394,7 @@ class dyagram:
         return None
 
     def discover_eigrp_neighbors(self, device):
-        #time.sleep(5) #FIXME: IF I DON'T PUT THIS HERE THERE IS AN EXCEPTION THROWN THAT I CAN'T CATCH
+
         try:
             self.log.info(f"DEVICE: {device} - RESTCONF : Discovering EIGRP Neighbors - START")
             discovered = self.discover_eigrp_neighbors_restconf()
@@ -426,18 +428,21 @@ class dyagram:
                 nm_args = self.netmiko_args_template.copy()
                 nm_args['host'] = device
                 nm_args['device_type'] = os
-                print(f"NETMIKO ARGS FROM COPY TEMPLATE: {nm_args}")
+
 
             else:
                 os = "cisco_ios"
+                nm_args = self.netmiko_args_template.copy()
+                nm_args['host'] = device
+                nm_args['device_type'] = os
                 #raise Exception("Unable to determine OS.")
             self.log.info("GOT DEVICE TYPE")
 
-            print("BEFORE SETTING CH")
+
             dev = ConnectHandler(**nm_args)
-            print("AFTER SETTING CH")
+
             dev.enable()
-            print("AFTER SETTING ENABLE")
+
 
             if os in ['cisco_ios', 'cisco_nxos', 'cisco_xr']:
                 eigrp_output = dev.send_command("show ip eigrp neighbors vrf all") #textfsm not currently supported for this command
@@ -560,7 +565,7 @@ class dyagram:
                 except:
                     tb = self.get_traceback()
                     self.log.info(f"DEVICE: {device} EXCEPTION22 IN _discover_lldp_neighbors_by_ssh: {tb}")
-            except Exception:
+            except:
                 tb = self.get_traceback()
                 self.log.info(f"DEVICE: {device} - SSH : ERROR DISCOVER LLDP NEIGHBORS - {tb}")
 
@@ -590,7 +595,7 @@ class dyagram:
 
             try:
                 resp = restconf_session.get(f"{restconf_session.base_url}/openconfig-interfaces:interfaces")
-            except Exception:
+            except:
                 tb = self.get_traceback()
                 self.log.info(f"DEVICE: {restconf_session.base_url} EXCEPTION01 THROWN IN _get_chassis_ids : {tb}")
                 #print(tb) LOG THIS
@@ -672,7 +677,7 @@ class dyagram:
                     neighbor_info['chassis_id'] = intf['neighbors']['neighbor'][0]['state']['chassis-id']
                     lldp_info_json['neighbors'].append(neighbor_info)
 
-        except Exception:
+        except:
             tb = self.get_traceback()
             self.log.info(f"DEVICE: {device} EXCEPTION01 THROWN IN _get_lldp_neighbors_restconf : {tb}")
 
@@ -779,48 +784,52 @@ class dyagram:
 
     def _get_hostname(self, netmiko_session=None, restconf_session=None):
 
+        try:
+            if not netmiko_session and restconf_session:
+                try:
+                    device = re.search('\d+\.\d+\.\d+\.\d+', restconf_session.base_url).group(1)
+                except:
+                    device = restconf_session.base_url
 
-        if not netmiko_session and restconf_session:
-            try:
-                device = re.search('\d+\.\d+\.\d+\.\d+', restconf_session.base_url).group(1)
-            except:
-                device = restconf_session.base_url
-
-            try:
-                self.log.info(f"DEVICE: {device} - RESTCONF_OPENCONFIG : Querying for hostname - START")
-                resp = restconf_session.get(f"{device}/openconfig-system:system/config/name")
-                if resp.status_code == 200:
-                    self.log.info(f"DEVICE: {device} - RESTCONF_OPENCONFIG : Querying hostname - SUCCESSFUL")
-                    return resp.json()['hostname']
-                if resp.status_code != 200:
-                    self.log.info(
-                        f"DEVICE: {device} - RESTCONF_OPENCONFIG : Querying hostname - FAILURE")
-                    # try nexus TEMPORARY
-                    self.log.info(
-                        f"DEVICE: {device} - RESTCONF_NXOS_OS_DEVICE_YANG : Querying hostname - START")
-                    resp = restconf_session.get(f"{device}/Cisco-NX-OS-device:System/name")
-
+                try:
+                    self.log.info(f"DEVICE: {device} - RESTCONF_OPENCONFIG : Querying for hostname - START")
+                    resp = restconf_session.get(f"{device}/openconfig-system:system/config/name")
                     if resp.status_code == 200:
+                        self.log.info(f"DEVICE: {device} - RESTCONF_OPENCONFIG : Querying hostname - SUCCESSFUL")
+                        return resp.json()['hostname']
+                    if resp.status_code != 200:
                         self.log.info(
-                            f"DEVICE: {device} - RESTCONF_NXOS_OS_DEVICE_YANG : Querying hostname - SUCCESSFUL")
-                        return resp.json()['name']
+                            f"DEVICE: {device} - RESTCONF_OPENCONFIG : Querying hostname - FAILURE")
+                        # try nexus TEMPORARY
+                        self.log.info(
+                            f"DEVICE: {device} - RESTCONF_NXOS_OS_DEVICE_YANG : Querying hostname - START")
+                        resp = restconf_session.get(f"{device}/Cisco-NX-OS-device:System/name")
+
+                        if resp.status_code == 200:
+                            self.log.info(
+                                f"DEVICE: {device} - RESTCONF_NXOS_OS_DEVICE_YANG : Querying hostname - SUCCESSFUL")
+                            return resp.json()['name']
+                        self.log.info(
+                            f"DEVICE: {device} - RESTCONF_NXOS_OS_DEVICE_YANG : Querying hostname - FAILURE")
+
+                except:
+
+                    tb = self.get_traceback()
                     self.log.info(
-                        f"DEVICE: {device} - RESTCONF_NXOS_OS_DEVICE_YANG : Querying hostname - FAILURE")
+                        f"DEVICE: {device} - RESTCONF_OPENCONFIG_AND_NXOS_OS_DEVICE_YANG_CATCHALL : Querying hostname - FAILURE - TB: {tb}")
 
-            except Exception:
+            else:
+                self.log.info(f"DEVICE: {netmiko_session.host} - SSH : Querying for hostname - START")
+                sh_run_output = netmiko_session.send_command("sh run | inc hostname")
+                hostname = re.search("hostname\s+(.*)", sh_run_output).group(1)
+                self.log.info(f"DEVICE: {netmiko_session.host} - SSH : Querying for hostname - SUCCESSFUL")
 
-                tb = self.get_traceback()
-                self.log.info(
-                    f"DEVICE: {device} - RESTCONF_OPENCONFIG_AND_NXOS_OS_DEVICE_YANG_CATCHALL : Querying hostname - FAILURE - TB: {tb}")
+                return hostname
+            return None
+        except:
+            tb = self.get_traceback()
+            self.log.info(f"DEVICE: {device} EXCEPTION THROWN IN _get_hostname : {tb}")
 
-        else:
-            self.log.info(f"DEVICE: {netmiko_session.host} - SSH : Querying for hostname - START")
-            sh_run_output = netmiko_session.send_command("sh run | inc hostname")
-            hostname = re.search("hostname\s+(.*)", sh_run_output).group(1)
-            self.log.info(f"DEVICE: {netmiko_session.host} - SSH : Querying for hostname - SUCCESSFUL")
-
-            return hostname
-        return None
 
     def _get_os_version(self, netmiko_session):
 
@@ -895,7 +904,7 @@ def main():
                 if args.dyagram_args[1].lower() == "new":
                     try:
                         s.make_new_site(args.dyagram_args[2])
-                    except Exception as e:
+                    except:
                         print("Missing argument : <site>")
                 if args.dyagram_args[1].lower() == "switch":
                     try:
